@@ -1895,4 +1895,276 @@ VOCABULARY = {
         'workman',
         'youngster',
     ],
+    'animals': [
+        'aardvark',
+        'albatross',
+        'alligator',
+        'alpaca',
+        'ant',
+        'anteater',
+        'antelope',
+        'ape',
+        'armadillo',
+        'baboon',
+        'badger',
+        'barracuda',
+        'bat',
+        'bear',
+        'beaver',
+        'bee',
+        'beetle',
+        'binturong',
+        'bird',
+        'bison',
+        'bluebird',
+        'boar',
+        'bobcat',
+        'buffalo',
+        'bull',
+        'butterfly',
+        'camel',
+        'capybara',
+        'caracal',
+        'caribou',
+        'cassowary',
+        'cat',
+        'cattle',
+        'chamois',
+        'cheetah',
+        'chicken',
+        'chimpanzee',
+        'chinchilla',
+        'chough',
+        'coati',
+        'cobra',
+        'cockroach',
+        'cod',
+        'cormorant',
+        'cow',
+        'coyote',
+        'crab',
+        'crane',
+        'cricket',
+        'crocodile',
+        'crow',
+        'cuckoo',
+        'curlew',
+        'deer',
+        'dhole',
+        'dingo',
+        'dinosaur',
+        'dog',
+        'dogfish',
+        'dolphin',
+        'donkey',
+        'dove',
+        'dragonfly',
+        'duck',
+        'dugong',
+        'dunlin',
+        'eagle',
+        'echidna',
+        'eel',
+        'eland',
+        'elephant',
+        'elk',
+        'emu',
+        'falcon',
+        'ferret',
+        'finch',
+        'fish',
+        'fisher',
+        'flamingo',
+        'fly',
+        'fossa',
+        'fox',
+        'frog',
+        'gaur',
+        'gazelle',
+        'gecko',
+        'genet',
+        'gerbil',
+        'giraffe',
+        'gnat',
+        'gnu',
+        'goat',
+        'goldfinch',
+        'goosander',
+        'goose',
+        'gorilla',
+        'goshawk',
+        'grasshopper',
+        'grouse',
+        'guanaco',
+        'gull',
+        'hamster',
+        'hare',
+        'hawk',
+        'hedgehog',
+        'heron',
+        'herring',
+        'hippopotamus',
+        'hoatzin',
+        'hoopoe',
+        'hornet',
+        'horse',
+        'human',
+        'hummingbird',
+        'hyena',
+        'ibex',
+        'ibis',
+        'iguana',
+        'impala',
+        'jackal',
+        'jaguar',
+        'jay',
+        'jellyfish',
+        'junglefowl',
+        'kangaroo',
+        'kingbird',
+        'kingfisher',
+        'kinkajou',
+        'kite',
+        'koala',
+        'kodkod',
+        'kookaburra',
+        'kouprey',
+        'kowari',
+        'langur',
+        'lapwing',
+        'lark',
+        'lechwe',
+        'lemur',
+        'leopard',
+        'lion',
+        'lizard',
+        'llama',
+        'lobster',
+        'locust',
+        'loris',
+        'louse',
+        'lynx',
+        'lyrebird',
+        'macaque',
+        'macaw',
+        'magpie',
+        'mallard',
+        'mammoth',
+        'manatee',
+        'mandrill',
+        'marmoset',
+        'marmot',
+        'meerkat',
+        'mink',
+        'mole',
+        'mongoose',
+        'monkey',
+        'moose',
+        'mosquito',
+        'mouse',
+        'myna',
+        'narwhal',
+        'newt',
+        'nightingale',
+        'nilgai',
+        'ocelot',
+        'octopus',
+        'okapi',
+        'olingo',
+        'opossum',
+        'orangutan',
+        'oryx',
+        'ostrich',
+        'otter',
+        'ox',
+        'owl',
+        'oyster',
+        'panther',
+        'parrot',
+        'panda',
+        'partridge',
+        'peafowl',
+        'pelican',
+        'penguin',
+        'pheasant',
+        'pig',
+        'pigeon',
+        'pika',
+        'pony',
+        'porcupine',
+        'porpoise',
+        'pug',
+        'quail',
+        'quelea',
+        'quetzal',
+        'rabbit',
+        'raccoon',
+        'ram',
+        'rat',
+        'raven',
+        'reindeer',
+        'rhea',
+        'rhinoceros',
+        'rook',
+        'saki',
+        'salamander',
+        'salmon',
+        'sandpiper',
+        'sardine',
+        'sassaby',
+        'seahorse',
+        'seal',
+        'serval',
+        'shark',
+        'sheep',
+        'shrew',
+        'shrike',
+        'siamang',
+        'skink',
+        'skipper',
+        'skunk',
+        'sloth',
+        'snail',
+        'snake',
+        'spider',
+        'spoonbill',
+        'squid',
+        'squirrel',
+        'starfish',
+        'starling',
+        'stilt',
+        'swan',
+        'tamarin',
+        'tapir',
+        'tarsier',
+        'termite',
+        'thrush',
+        'tiger',
+        'toad',
+        'topi',
+        'toucan',
+        'turaco',
+        'turkey',
+        'turtle',
+        'vicuna',
+        'vinegaroon',
+        'viper',
+        'vulture',
+        'wallaby',
+        'walrus',
+        'wasp',
+        'waxwing',
+        'weasel',
+        'whale',
+        'wildebeest',
+        'wobbegong',
+        'wolf',
+        'wolverine',
+        'wombat',
+        'woodpecker',
+        'worm',
+        'wren',
+        'yak',
+        'zebra',
+    ],
 }
